@@ -2,6 +2,6 @@ from .aa import AA, AAInfo
 from .base import Base
 from .database import *
 from .enzyme import Enzyme
-from .mass import Mass
+from .mass import CompoundMass, Mass
 from .mod import BasicModification
 from .xler import XLer
