@@ -1,12 +1,61 @@
+import numpy as np
+import pandas as pd
+
+
+def sum_list(nested_list):
+    temp = []
+    for _ in nested_list:
+        temp.extend(_)
+        return temp
+
+
+flatten_list = sum_list
+
+
+def recursive_sum_list(nested_list: list) -> list:
+    """
+    Recursively flatten list consist of both list/tuple and un-iterable items
+    TODO append method will take much time?
+        # inner_item_is_list = [isinstance(_, _) for _ in l]
+        # if any(inner_item_is_list):
+    """
+    temp = []
+    for item in nested_list:
+        if isinstance(item, (list, tuple)):
+            temp.extend(recursive_sum_list(item))
+        else:
+            temp.append(item)
+    return temp
+
 
 def sum_set_in_list(list_with_sets, return_type='set'):
-    summed_list = sum([list(each_set) for each_set in list_with_sets], [])
+    union_set = list_with_sets[0]
+    if len(list_with_sets) >= 2:
+        for s in list_with_sets[1:]:
+            union_set = union_set | s
     if return_type == 'set':
-        return set(summed_list)
+        return union_set
     elif return_type == 'list':
-        return summed_list
+        return list(union_set)
     else:
-        print('Not supported return type when sum set list')
+        raise ValueError('Not supported return type when sum set list')
+
+
+def align_dict(*dn: dict, columns=None):
+    aligned_list = []
+    key_union = sorted(set(sum_list(dn)))
+    for key in key_union:
+        aligned_list.append([di.get(key, np.nan) for di in dn])
+    if columns is None:
+        columns = [f'D{i}' for i in range(1, len(dn) + 1)]
+    return pd.DataFrame(aligned_list, index=key_union, columns=columns)
+
+
+def split_two_set(set1, set2):
+    overlapped = set1 & set2
+    set1_unique = set1 - set2
+    set2_unique = set2 - set1
+    return set1_unique, overlapped, set2_unique
 
 
 def drop_list_duplicates(initial_list):
@@ -31,7 +80,7 @@ def subtract_list(list_1, list_2, drop_duplicates=True):
         return subtracted_list
 
 
-def get_coincide_data(dict_1, dict_2):
+def get_dict_coincide_data(dict_1, dict_2):
     shared_keys = list(set(dict_1.keys()) & set(dict_2.keys()))
     value_list_1 = [dict_1[_] for _ in shared_keys]
     value_list_2 = [dict_2[_] for _ in shared_keys]
@@ -44,9 +93,20 @@ def str_mod_to_list(mod):
     return mod_list
 
 
-def check_list_len_in_dict(checked_dict):
-    for name, one_list in checked_dict.items():
-        print(f'{name}: {len(one_list)}')
+def check_value_len_of_dict(checked_dict: dict, thousands_separator=True, sort_keys=False, ):
+    # TODO sort_keys 可以为 lambda 函数
+    # TODO return length dict or print
+    if sort_keys:
+        keys = sorted(checked_dict.keys())
+    else:
+        keys = checked_dict.keys()
+    for k in keys:
+        v = checked_dict[k]
+        v_len = len(v)
+        if thousands_separator:
+            print(f'{k}: {format(v_len, ",")}')
+        else:
+            print(f'{k}: {v_len}')
 
 
 class XmlListConfig(list):
